public class makeall {
    //dx.applets.imageWindow		f01;
    dx.net.DXLinkApplication 		a01;
    dx.net.DXApplication 		a02;
    dx.net.ImageWindow 			a03;
    dx.net.DXLinkHandler 		a04;
    dx.net.ControlPanel 		a05;
    dx.net.Network 			a06;
    dx.net.SelectionNode 		a07;
    dx.net.BinaryNode 			a08;
    dx.net.InteractorNode 		a09;
    dx.net.DrivenNode 			a0a;
    dx.net.Node 			a0b;
    dx.net.PacketIF 			a0c;
    dx.net.PickNode 			a0d;
    dx.net.WebOptionsNode 		a0e;
    dx.net.ImageNode 			a0f;
    dx.net.ToggleNode 			a11;
    dx.net.ScalarNode 			a12;
    dx.net.ValueNode 			a13;
    dx.net.DXLOutputNode 		a14;
    dx.net.SequencerNode 		a15;
    dx.net.DXLAppThread 		a16;
    dx.net.DXViewIF 			a17;
    dx.net.Gnomon 			a18;
    dx.net.CfgValues 			a19;
    dx.net.Arc 				a1a;
    dx.net.NumericValues 		a1b;
    dx.net.DXLAppThreadCommand 		a1c;
    dx.net.ResetNode			a1d;
    dx.client.DXClient 			a1e;
    dx.client.AppletClient 		a1f;
    dx.client.DXClientThread 		a20;
    dx.client.StopThread 		a21;
    dx.client.AppletLoadThread 		a22;
    dx.client.DXClientThreadCommand 	a23;
    dx.runtime.Selector 		a24;
    dx.runtime.BinaryInstance 		a25;
    dx.runtime.Interactor 		a26;
    dx.runtime.Toggle 			a27;
    dx.runtime.StepperInteractor 	a29;
    dx.runtime.RadioGroup 		a2a;
    dx.runtime.ListSelector 		a2b;
    dx.runtime.LabelGroup 		a2c;
    dx.runtime.StepperGroup 		a2d;
    dx.runtime.Stepper 			a2e;
    dx.runtime.ArrowButton 		a2f;
    dx.runtime.ToggleGroup		a30;
    dx.runtime.ScalarInteractor		a31;
    dx.runtime.StringInteractor		a32;
    dx.runtime.Separator		a33;
    dx.protocol.server.serverMsg 	a34;
    dx.protocol.server.statusMsg 	a35;
    dx.protocol.server.startMsg 	a36;
    dx.protocol.server.serverVersionMsg a37;
    dx.protocol.message 		a38;
    dx.protocol.threadMsg 		a39;
    dx.protocol.uptimeMsg 		a3a;
    dx.protocol.visitsMsg 		a3b;
    dx.protocol.usersMsg 		a3c;
    dx.protocol.loadMsg 		a3d;
    dx.protocol.execOnceMsg 		a3e;
    dx.protocol.stepSeqMsg 		a3f;
    dx.protocol.endExecMsg 		a40;
    dx.protocol.sendValueMsg 		a41;
    dx.protocol.messageMsg 		a42;
    dx.protocol.doneMsg 		a43;
    dx.protocol.setidMsg 		a44;
    dx.protocol.setmacroMsg 		a45;
    layout.SingleFiledLayout	a46;
    layout.TableLayoutConstants	a47;
    layout.TableLayout			a48;
    layout.TableLayoutConstraints	a49;
}
